/*
Example for Buck Click

    Date          : jul 2017.
    Author        : MikroE Team

Test configuration PIC :
    
    MCU             : P18F87K22
    Dev. Board      : EasyPIC PRO v7
    SW              : mikroC PRO for PIC v7.1.0

Description :

    A simple example of using Buck click, to set Vout to 3.3V or 5V just set the jumper on the appropriate place on the click.      
    The switching frequency  is regulated by MUX 4634 by setting pins A0 and A1 in following way:      
    A0 = 0 and A1 = 0 for 0.4 MHz	  	 
    A0 = 0 and A1 = 1 for 1.2 MHz	 	 
    A0 = 1 and A1 = 0 for 0.8 MHz	 	 
    A0 = 1 and A1 = 1 for 1.6 MHz	

*/
sbit MUX_A0_PIN at PORTC.B0;
sbit MUX_A0_PIN_Direction at TRISC.B0;

sbit BUCK_ENABLE_PIN at PORTE.B0;
sbit BUCK_ENABLE_PIN_Direction at TRISE.B0;

sbit MUX_A1_PIN at PORTC.B1;
sbit MUX_A1_PIN_Direction at TRISC.B1;

sbit PG_PIN at PORTB.B0;
sbit PG_PIN_Direction at TRISB.B0;

void systemInit()
{
    ANCON0 = 0x00;
    ANCON1 = 0x00;
    ANCON2 = 0x00;  
    UART1_Init(9600);    
}

void Buck_Init()
{
    MUX_A0_PIN_Direction = 0;
    BUCK_ENABLE_PIN_Direction = 0;
    MUX_A1_PIN_Direction = 0;
    PG_PIN_Direction = 1;
    BUCK_ENABLE_PIN = 1;
    MUX_A0_PIN = 0;
    MUX_A1_PIN = 0;   
}

void Buck_Task()
{
    if (PG_PIN == 1)
    {
        UART1_Write_text("Vout is within the final 8.4% of final regulation voltage");
        UART1_Write_Text( "\r\n" );
        delay_ms(1000);
    }
}

void main()
{
    systemInit();
    Buck_Init();

    while( 1 )
    {
    	Buck_Task();
    }
}
